@@ -24,28 +24,34 @@
 #define FILE_DATA_H
 
 #include <glib.h>
+#include <glib-object.h>
 #include <time.h>
 
 typedef struct {
-	char *     original_path;
-	char *     full_path;
-	char *     link;
-	long int   size;
-	time_t     modified;
+	char       *original_path;    /* path read from command line. */
+	char       *full_path;        /* "/" + original_path. */
+	char       *link;
+	long long   size;
+	time_t      modified;
 
-	char *       name;
-	char *       path;
-	const char * type;
+	char       *name;             /* The file name. */
+	char       *path;             /* The directory. */
+	const char *type;             /* The mime type. */
 
-	/* additional data. */
-	gboolean   is_dir;
-	char *     list_name;
+	/* Additional data. */
+
+	gboolean    is_dir;           /* Whether this entry is used to show
+				       * a directory. */
+	char       *list_name;        /* The string visualized in the list
+				       * view. */
 } FileData;
 
+#define FR_TYPE_FILE_DATA (file_data_get_type ())
 
-FileData *  file_data_new     ();
-
-void        file_data_free    (FileData *fdata);
-
+GType           file_data_get_type             (void);
+FileData *      file_data_new                  (void);
+FileData *      file_data_copy                 (FileData *src);
+void            file_data_free                 (FileData *fdata);
+const char *    file_data_get_type_description (const FileData *fdata);
 
 #endif /* FILE_DATA_H */
