@@ -26,7 +26,6 @@
 #include <time.h>
 
 #include <glib.h>
-#include <gnome.h>
 #include <libgnomevfs/gnome-vfs-types.h>
 #include <libgnomevfs/gnome-vfs-mime.h>
 
@@ -140,6 +139,10 @@ list__process_line (char     *line,
 		return;
 
 	line_l = strlen (line);
+
+	if (line_l == 0)
+		return;
+
 	if (line_l > EMPTY_ARCHIVE_WARNING_LENGTH) 
 		if (strcmp (line + line_l - EMPTY_ARCHIVE_WARNING_LENGTH, 
 			    EMPTY_ARCHIVE_WARNING) == 0) {
@@ -152,7 +155,7 @@ list__process_line (char     *line,
 	fdata = file_data_new ();
 
 	fields = split_line (line, 7);
-	fdata->size = atol (fields[0]);
+	fdata->size = atoll (fields[0]);
 	fdata->modified = mktime_from_string (fields[4], fields[5]);
 	g_strfreev (fields);
 
@@ -217,8 +220,6 @@ add_password_arg (FRCommand     *comm,
 static void
 fr_command_zip_list (FRCommand *comm)
 {
-
-
 	FR_COMMAND_ZIP (comm)->is_empty = FALSE;
 
 	fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
