@@ -427,7 +427,7 @@ _gtk_error_dialog_new (GtkWindow        *parent,
                                         GTK_POLICY_AUTOMATIC, 
                                         GTK_POLICY_AUTOMATIC);
         gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
-                                             GTK_SHADOW_NONE /*ETCHED_IN*/);
+                                             GTK_SHADOW_ETCHED_IN);
 	gtk_widget_set_size_request (scrolled, -1, 200);
 
 	text_buf = gtk_text_buffer_new (NULL);
@@ -534,7 +534,10 @@ _gtk_entry_set_locale_text (GtkEntry   *entry,
 	char *utf8_text;
 
 	utf8_text = g_locale_to_utf8 (text, -1, NULL, NULL, NULL);
-	gtk_entry_set_text (entry, utf8_text);
+	if (utf8_text != NULL)
+		gtk_entry_set_text (entry, utf8_text);
+	else
+		gtk_entry_set_text (entry, "");
 	g_free (utf8_text);
 }
 
@@ -562,8 +565,11 @@ _gtk_label_set_locale_text (GtkLabel   *label,
 	char *utf8_text;
 
 	utf8_text = g_locale_to_utf8 (text, -1, NULL, NULL, NULL);
-	gtk_label_set_text (label, utf8_text);
-	g_free (utf8_text);
+	if (utf8_text != NULL) {
+		gtk_label_set_text (label, utf8_text);
+		g_free (utf8_text);
+	} else
+		gtk_label_set_text (label, "");
 }
 
 
@@ -590,11 +596,11 @@ _gtk_entry_set_filename_text (GtkEntry   *entry,
 	char *utf8_text;
 
 	utf8_text = g_filename_to_utf8 (text, -1, NULL, NULL, NULL);
-	if (utf8_text != NULL)
+	if (utf8_text != NULL) {
 		gtk_entry_set_text (entry, utf8_text);
-	else
+		g_free (utf8_text);
+	} else
 		gtk_entry_set_text (entry, "");
-	g_free (utf8_text);
 }
 
 
